@@ -168,7 +168,7 @@ void CallListener::requestFinished(QVector <Source::Result> const& results,
         if(retries_ < SEARCH_RETRIES && retries_ >= 0)
         {
             retries_++;
-            source_->search(Source::SearchDetails(currentSearch_));
+            source_->search(Source::SearchDetails(currentSearch_, "", Source::BOTH));
             return;
         }
         else
@@ -265,7 +265,7 @@ void CallListener::incomingCall(QDBusObjectPath path, QString number)
                            this,
                            SLOT(callTerminate()));
 
-        search(Source::SearchDetails(number));
+        search(Source::SearchDetails(number, "", Source::BOTH));
     }
     else
     {
