@@ -16,23 +16,20 @@
  *
  */
 
-#include <QtCore/QTranslator>
-#include <QtCore/QLocale>
-#include <QtGui/QApplication>
 #include <QtCore/QObject>
+#include <QtGui/QApplication>
 #include "mainwindow.h"
 #include "searchdialog.h"
 #include "resultwindow.h"
 #include "detailwindow.h"
 #include "eniro.h"
+#include "settings.h"
 
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
 
-    QTranslator translator;
-    translator.load(":/translations/" + QLocale::system().name());
-    app.installTranslator(&translator);
+    Settings::instance()->loadLanguage(app);
 
     MainWindow window;
     ResultWindow results(&window);
@@ -43,8 +40,8 @@ int main(int argc, char *argv[])
     QObject::connect(&window, SIGNAL(search(SearchDialog::SearchDetails&)),
                      &results, SLOT(search(SearchDialog::SearchDetails&)));
 
-    QObject::connect(&results, SIGNAL(itemSelected(Eniro::Result const&)),
-                     &details, SLOT(loadData(Eniro::Result const&)));
+    QObject::connect(&results, SIGNAL(itemSelected(Source::Result const&)),
+                     &details, SLOT(loadData(Source::Result const&)));
 
     return app.exec();
 }
