@@ -158,7 +158,7 @@ void MainWindow::toggleDaemon()
     }
     else
     {
-        QMaemo5InformationBox::information(this, readyText);
+        QMaemo5InformationBox::information(this, readyText, 800);
         toggleButton_->setText(buttonText);
         toggleButton_->setIcon(QIcon(running_ ? START_ICON : CLOSE_ICON));
         running_ = !running_;
