@@ -169,17 +169,16 @@ void SettingsDialog::saveSettings()
 
     Settings::instance()->endEdit();
 
-    if(Daemon::isRunning())
-    {
-        QMaemo5InformationBox::information(this, tr("Restarting daemon..."), 1500);
-        Daemon::restart();
-    }
-
     if(language != selectedLanguage_)
     {
         QMaemo5InformationBox::information(this, tr("You need to restart Jenirok for language change to take effect."));
         selectedLanguage_ = language;
     }
+    else if(Daemon::isRunning())
+    {
+        QMaemo5InformationBox::information(this, tr("Restarting daemon..."), 1500);
+        Daemon::restart();
+    }
 
 }
 
